# coding: utf-8

"""
    Papermerge REST API

    Document management system designed for digital archives  # noqa: E501

    The version of the OpenAPI document: 2.1.0b12
    Generated by: https://openapi-generator.tech
"""

import unittest

import papermerge_restapi_client
from papermerge_restapi_client.model.node_move import NodeMove
from papermerge_restapi_client import configuration


class TestNodeMove(unittest.TestCase):
    """NodeMove unit test stubs"""
    _configuration = configuration.Configuration()


if __name__ == '__main__':
    unittest.main()
