from papermerge_restapi_client.paths.api_pages_id_.get import ApiForget
from papermerge_restapi_client.paths.api_pages_id_.delete import ApiFordelete


class ApiPagesId(
    ApiForget,
    ApiFordelete,
):
    pass
