from papermerge_restapi_client.paths.api_groups_.get import ApiForget
from papermerge_restapi_client.paths.api_groups_.post import ApiForpost


class ApiGroups(
    ApiForget,
    ApiForpost,
):
    pass
