from papermerge_restapi_client.paths.api_tokens_.get import ApiForget
from papermerge_restapi_client.paths.api_tokens_.post import ApiForpost


class ApiTokens(
    ApiForget,
    ApiForpost,
):
    pass
