from papermerge_restapi_client.paths.api_preferences_id_.get import ApiForget
from papermerge_restapi_client.paths.api_preferences_id_.put import ApiForput
from papermerge_restapi_client.paths.api_preferences_id_.patch import ApiForpatch


class ApiPreferencesId(
    ApiForget,
    ApiForput,
    ApiForpatch,
):
    pass
